//=============================================================================
// Stat List EX - By TomatoRadio
// TR_StatListEX.js
//=============================================================================

//=============================================================================
 /*:
 * @author TomatoRadio
 * @plugindesc
 * Allows more dynamic stat displays.
 * Version 1.0
 * 
 * @help
 * ============================================================================
 * USAGE
 * ============================================================================
 * 
 * In an actor's notetags, add BOTH of these notetags.
 * 
 * <MenuStats:x,y,z>
 * Where X, Y, and X are shorthands for any Param, XParam, or SParam in the order you want on the menu. 
 * You may also place a number to refer to the Variable of that ID.
 * 
 * <MenuStatNames:Name,Name,Name> Where Names are the names that each stat will be called in the menu.
 * Please exclude spaces after the commas in both of these. So <item,item,item>
 * Not <item, item, item>
 * 
 * I have only made menu size adjustments for actors with 8 listed stats. 9 or more will likely stop displaying.
 * I have made cases for 6 and 5 stats, where there will be greater spacing. 4 or less uses the same spacing as 5.
 * 
 * If MenuStats is not present, the game will default back to the basegame stat list and names.
 * Is MenuStats is present but MenuStatNames is not the game will crash.
 * No I will not fix this because if you're using one you should have the other stupid.
 * 
 * For ease of use, here are all stat shorthands as reference:
 * MHP = MAX HP / HEART
 * MMP = MAX MP / JUICE
 * ATK = ATTACK
 * DEF = DEFENSE
 * MAT = MAGIC ATTACK
 * MDF = MAGIC DEFENSE
 * AGI = AGILITY / SPEED
 * LUK = LUCK
 * HIT = HIT RATE
 * EVA = EVASION
 * CRI = CRITICAL RATE
 * CEV = CRITICAL EVASION
 * MEV = MAGIC EVASION
 * MRF = MAGIC REFLECTION
 * CNT = COUNTER ATTACK
 * HRG = HP REGENERATION
 * MRG = MP REGENERATION
 * TRG = TP REGENERATION
 * TGR = TARGET RATE
 * GRD = GUARD EFFECT RATE
 * REC = RECOVERY RATE
 * PHA = PHARMACOLOGY
 * MCR = My Chemi- I-i mean MP COST RATE
 * TCR = TP CHARGE RATE
 * PDR = PHYSICAL DAMAGE
 * MDR = MAGIC DAMAGE
 * FDR = FLOOR DAMAGE
 * EXR = EXPERIENCE
 */
//=============================================================================

var Imported = Imported || {};
Imported.TR_StatListEX = true;

var TR = TR || {};
TR.SLEX = TR.SLEX || {};
TR.SLEX.version = 1.0;

//=============================================================================
// * Object Initialization
//=============================================================================
Window_OmoMenuEquipStatus.prototype.initialize = function() {
  // Super Call
  Window_Base.prototype.initialize.call(this, 0, 0, this.windowWidth(), this.windowHeight());
  // Create Bubble Sprites
  this.createBubbleSprites();   
  // Parameters to draw (Use 100+ for Xparam, 200+ For Sparam)
  this._params = [0,1,2,3,6,7,100];
  this._paramNames = ['HEART','JUICE','ATTACK','DEFENSE','SPEED','LUCK','HIT']
  //this._params = [0,1,2,3,4,5,6,7,100,101,102,103,104,105,106,107,108,109,200,201,202,203,204,205,206,207,208,209];
  // Set Actor & Temp actor to null
  this._actor = null; this._tempActor = null
  // Set Openness to 0
  this.openness = 0; 
  // Refresh
  this.refresh();
};
//=============================================================================
// * Refresh
//=============================================================================
Window_OmoMenuEquipStatus.prototype.refresh = function() {
  // Clear Contents
  this.contents.clear();
  // Get Actor
  var actor = this._actor;
  // If Actor Exists
  if (actor) {
    // Get Arrow Bitmap
    var bitmap = ImageManager.loadSystem('equip_arrow');
    // Stats (Use 100+ for Xparam, 200+ For Sparam)
    var stats = this._params;
    var statNames = this._paramNames;
    if (actor.meta.MenuStats) {
      stats = actor.meta.MenuStats.trim().split(',');
      statNames = actor.meta.MenuStatNames.trim().split(',');
    };
    // Go Through Stats
    for (var i = 0; i < stats.length; i++) {
      // Get Param Index
      var paramIndex = stats[i];
      var paramSub = Array.isArray(paramIndex) ? paramIndex[1] : null;
      if (paramSub) { paramIndex = paramIndex[0]; }
      // Get First Value
      var value1 = Math.floor(this.actorParamValue(actor, paramIndex));
      // Get Param Name
      var paramName = statNames[i];
      var spacing = 21 //Dummy Value
      if (stats.length > 7) {
        spacing = 18
      } else if (stats.length < 7) {
        spacing = 24
      } else {
        spacing = 21
      }
      this.contents.fontSize = 20;
      this.drawText(paramName + ':', 8, -5 + i * spacing, 100)    
      this.drawText(value1, 132, -5 + i * spacing, 100)
      this.contents.blt(bitmap, 0, 0, bitmap.width, bitmap.height, 173, 13 + i * spacing)
      // If Temp Actor Exists
      if (this._tempActor) {
        var value2 = Math.floor(this.actorParamValue(this._tempActor, paramIndex));
        this.resetTextColor();
        if (value1 < value2) {  this.contents.textColor = "#69ff90";}
        if (value1 > value2) {  this.contents.textColor = "#ff2b2b";}        
      } else {
        var value2 = '---';
      }
      this.drawText(value2, 132 + 56, -5 + i * spacing, 100)
      this.resetTextColor();      
    };
  };
};

Window_OmoMenuEquipStatus.prototype.actorParamValue = function(actor, param) {
switch (param.toLowerCase()) {
  case "mhp":
    return actor.mhp
  case "mmp":
    return actor.mmp
  case "atk":
    return actor.atk
  case "def":
    return actor.def
  case "mat":
    return actor.mat
  case "mdf":
    return actor.mdf
  case "agi":
    return actor.agi
  case "luk":
    return actor.luk
  case "hit":
    return actor.hit * 100
  case "eva":
    return actor.eva * 100
  case "cri":
    return actor.cri * 100
  case "cev":
    return actor.cev * 100
  case "mev":
    return actor.mev * 100
  case "mrf":
    return actor.mrf * 100
  case "cnt":
    return actor.cnt * 100
  case "hrg":
    return actor.hrg * 100
  case "mrg":
    return actor.mrg * 100
  case "trg":
    return actor.trg * 100
  case "tgr":
    return actor.tgr * 100
  case "grd":
    return actor.grd * 100
  case "rec":
    return actor.rec * 100
  case "pha":
    return actor.pha * 100
  case "mcr":
    return actor.mcr * 100
  case "tcr":
    return actor.tcr * 100
  case "pdr":
    return actor.pdr * 100
  case "mdr":
    return actor.mdr * 100
  case "tdr":
    return actor.tdr * 100
  case "exr":
    return actor.exr * 100
  default:
    param = parseInt(param);
    return $gameVariables.value(param);
}
};

//This fixes evasion and hitrate being seperate stats in calculations. Now evasion will reduce the hitrate of the attacker
Game_Action.prototype.itemHit = function(target) {
    if (this.isPhysical()) {
        return this.item().successRate * 0.01 * this.subject().hit - target.eva;
    } else {
        return this.item().successRate * 0.01;
    }
};

Game_Action.prototype.itemEva = function(target) {
    if (this.isPhysical()) {
        return 0;
    } else if (this.isMagical()) {
        return 0;
    } else {
        return 0;
    }
};